==> haskell-unliftio-0.1.0.0-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.1.0.0
id: unliftio-0.1.0.0-EyJhviKZkDaHKezSnXvFk8
key: unliftio-0.1.0.0-EyJhviKZkDaHKezSnXvFk8
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/monad-unlift/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the README.md file for details
category: Control
author: Michael Snoyman, Francesco Mazzoli
exposed: True
indefinite: False
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Exception
    UnliftIO.IO UnliftIO.IORef UnliftIO.Instances UnliftIO.MVar
    UnliftIO.Resource UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
abi: 23b5393bc815b80d941e99325e74c07d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unliftio-0.1.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/unliftio-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/unliftio-0.1.0.0
hs-libraries: HSunliftio-0.1.0.0-EyJhviKZkDaHKezSnXvFk8
depends:
    base-4.10.0.0 async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    monad-logger-0.3.25.1-8lZjdCQwuyLHjwWHPCsxdR
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9 transformers-0.5.2.0
    unliftio-core-0.1.0.0-7dxXCheCbWw5AYq7pnmhLl unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             monad-logger-0.3.25.1-8lZjdCQwuyLHjwWHPCsxdR=4a866108f3c15e274103501b95a15632
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unliftio-core-0.1.0.0-7dxXCheCbWw5AYq7pnmhLl=5342fc877b9186e2d07ec8389a5daa43
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-0.1.0.0-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.1.0.0
id: unliftio-0.1.0.0-I5Ls4SRq9vHBahJx980RYI
key: unliftio-0.1.0.0-I5Ls4SRq9vHBahJx980RYI
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/monad-unlift/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the README.md file for details
category: Control
author: Michael Snoyman, Francesco Mazzoli
exposed: True
indefinite: False
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Exception
    UnliftIO.IO UnliftIO.IORef UnliftIO.Instances UnliftIO.MVar
    UnliftIO.Resource UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
abi: ab025293953e2496b0c6cdd8f7c4cc01
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unliftio-0.1.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/unliftio-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/unliftio-0.1.0.0
hs-libraries: HSunliftio-0.1.0.0-I5Ls4SRq9vHBahJx980RYI
depends:
    base-4.10.0.0 async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc deepseq-1.4.3.0
    directory-1.3.0.2 filepath-1.4.1.2
    monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9 transformers-0.5.2.0
    unliftio-core-0.1.0.0-7dxXCheCbWw5AYq7pnmhLl unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             monad-logger-0.3.25.1-CwaXwQJnYksLl9woJRYT1i=5ca2af848924c38076b16946ad67a1a4
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unliftio-core-0.1.0.0-7dxXCheCbWw5AYq7pnmhLl=5342fc877b9186e2d07ec8389a5daa43
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
